LamsonProject: $title

#

- Home
- News
- Feed
- Download
- Documentation
- API

# $title

$content

- Latest News
- Download the Gear
- Getting Started
- Documentation
- Frequently Asked Questions
- About Lamson
- Getting Help with Lamson

### Quick Start

See the download instructions for information on getting lamson, and read the getting started instructions to start your own application in less than 10 minutes.

### Mailing Lists

Lamson hosts its own mailing lists as well as provides a free open mailing list service for anyone who needs one. Simply send an email to the list you want at lists.lamsonproject.org and it will get you started.

Lamson Project(TM) and all material on this site Copyright © 2009 Zed Shaw unless otherwise stated.
Website Designed by Kenneth Keitner and donated to the LamsonProject.